@@ -21,9 +21,9 @@
 #include "core/Bootstrap.h"
 #include "core/Config.h"
 #include "core/Global.h"
-#include "core/PasswordGenerator.h"
 #include "core/Tools.h"
 #include "crypto/Crypto.h"
+#include "keys/drivers/YubiKey.h"
 #include "format/Kdbx3Reader.h"
 #include "format/Kdbx3Writer.h"
 #include "format/Kdbx4Reader.h"
@@ -1682,14 +1682,15 @@ void TestCli::testShow()
     QCOMPARE(m_stdoutFile->readAll(),
              QByteArray("Title: Sample Entry\n"
                         "UserName: User Name\n"
-                        "Password: Password\n"
+                        "Password: PROTECTED\n"
                         "URL: http://www.somesite.com/\n"
                         "Notes: Notes\n"));
 
     qint64 pos = m_stdoutFile->pos();
     Utils::Test::setNextPassword("a");
-    showCmd.execute({"show", m_dbFile->fileName(), "-q", "/Sample Entry"});
+    showCmd.execute({"show", "-s", m_dbFile->fileName(), "/Sample Entry"});
     m_stdoutFile->seek(pos);
+    m_stdoutFile->readLine(); // skip password prompt
     QCOMPARE(m_stdoutFile->readAll(),
              QByteArray("Title: Sample Entry\n"
                         "UserName: User Name\n"
@@ -1697,6 +1698,17 @@ void TestCli::testShow()
                         "URL: http://www.somesite.com/\n"
                         "Notes: Notes\n"));
 
+    pos = m_stdoutFile->pos();
+    Utils::Test::setNextPassword("a");
+    showCmd.execute({"show", m_dbFile->fileName(), "-q", "/Sample Entry"});
+    m_stdoutFile->seek(pos);
+    QCOMPARE(m_stdoutFile->readAll(),
+             QByteArray("Title: Sample Entry\n"
+                        "UserName: User Name\n"
+                        "Password: PROTECTED\n"
+                        "URL: http://www.somesite.com/\n"
+                        "Notes: Notes\n"));
+
     pos = m_stdoutFile->pos();
     Utils::Test::setNextPassword("a");
     showCmd.execute({"show", "-a", "Title", m_dbFile->fileName(), "/Sample Entry"});
@@ -1704,6 +1716,13 @@ void TestCli::testShow()
     m_stdoutFile->readLine(); // skip password prompt
     QCOMPARE(m_stdoutFile->readAll(), QByteArray("Sample Entry\n"));
 
+    pos = m_stdoutFile->pos();
+    Utils::Test::setNextPassword("a");
+    showCmd.execute({"show", "-a", "Password", m_dbFile->fileName(), "/Sample Entry"});
+    m_stdoutFile->seek(pos);
+    m_stdoutFile->readLine(); // skip password prompt
+    QCOMPARE(m_stdoutFile->readAll(), QByteArray("Password\n"));
+
     pos = m_stdoutFile->pos();
     Utils::Test::setNextPassword("a");
     showCmd.execute({"show", "-a", "Title", "-a", "URL", m_dbFile->fileName(), "/Sample Entry"});
